@@ -87,9 +87,9 @@ def get_args_and_run():
     args = parser.parse_args()
     print(f"args.action = .{args.action}.")
     if(args.action == "start_rx"):
-        start_rx(args.runsecs)
+        start_rx(int(args.runsecs))
     if(args.action == "start_tx"):
-        start_tx(args.runsecs)
+        start_tx(int(args.runsecs))
     if(args.action == "do_plots"):
         do_plots()
         
